==> imwiki-0.6.0.tar.gz: imwiki-0.6.0/imLib/Request.py <==
# -*- coding: utf8 -*-
import os
import cgi

import utils
import config

class Singleton(object): 
	def __new__(klass, *args, **kws):
		instance = klass.__dict__.get("__instance__") 
		if instance is not None: 
			return instance
		klass.__instance__ = instance = object.__new__(klass) 
		return instance


class Request(Singleton):
	def __init__(self):
		if 'isFirst' not in self.__dict__.keys():
			self.init()
	def init(self):
		self.env = os.environ
		self.form = cgi.FieldStorage()
			
		self.action = self.form.getvalue('action', 'view')
		self.scriptName =  self.env.get('SCRIPT_NAME', '')
		pathInfo = self.env.get('PATH_INFO', '')
		pathInfo = utils.decode(pathInfo)
		pathInfo = self._toMyCharset(pathInfo)
		while pathInfo and pathInfo[-1] == '/':
			pathInfo = pathInfo[:-1]
		splitedPath = pathInfo.split('/')
		self.pageName = splitedPath[-1] or 'FrontPage' 
		#self.pageName = utils.decode(pageName)
		self.categoryPath = self.form.getvalue('categoryPath', None) or '/'.join(splitedPath[1:-1])
		self.actionPath = self.scriptName + '/' + utils.joinPath(utils.encode(self.categoryPath), utils.encode(self.pageName)) # FIXME categoryPath, pageName이 join이면 pathInfo아닌가? 왜 따로하지? 아..폼에서도 넘어오네..폼에서 넘어올 필요가 있나?
		self.isFirst = True
	def _toMyCharset(self, text, charset=config.charset): 
		try:
			text = text.decode('UTF-8').encode(charset)
		except UnicodeError:
			pass
		return text

		
	def __getattr__(self, key):
		if key in self.__dict__.keys():
			return self.__dict__.get(key)
		return self.form.getvalue(key, '')

==> imwiki-0.6.2.tar.gz: imwiki-0.6.2/imLib/Request.py <==
# -*- coding: utf8 -*-
import os
import cgi

import utils
import config

class Singleton(object): 
	def __new__(klass, *args, **kws):
		instance = klass.__dict__.get("__instance__") 
		if instance is not None: 
			return instance
		klass.__instance__ = instance = object.__new__(klass) 
		return instance


class Request(Singleton):
	def __init__(self):
		if 'isFirst' not in self.__dict__.keys():
			self.init()
	def init(self):
		self.env = os.environ
		self.form = cgi.FieldStorage()
			
		self.action = self.form.getvalue('action', 'view')
		self.scriptName =  self.env.get('SCRIPT_NAME', '')
		pathInfo = self.env.get('PATH_INFO', '')
		pathInfo = utils.decode(pathInfo)
		pathInfo = self._toMyCharset(pathInfo)
		while pathInfo and pathInfo[-1] == '/':
			pathInfo = pathInfo[:-1]
		splitedPath = pathInfo.split('/')
		self.pageName = splitedPath[-1] or 'FrontPage' 
		#self.pageName = utils.decode(pageName)
		self.categoryPath = self.form.getvalue('categoryPath', None) or '/'.join(splitedPath[1:-1])
		self.setActionPath(self.categoryPath, self.pageName)
		self.isFirst = True

	def setActionPath(self, categoryPath, pageName):
		self.actionPath = self.scriptName + '/' + utils.joinPath(utils.encode(categoryPath), utils.encode(pageName)) # FIXME categoryPath, pageName이 join이면 pathInfo아닌가? 왜 따로하지? 아..폼에서도 넘어오네..폼에서 넘어올 필요가 있나?
	def _toMyCharset(self, text, charset=config.charset): 
		try:
			text = text.decode('UTF-8').encode(charset)
		except UnicodeError:
			pass
		return text

		
	def __getattr__(self, key):
		if key in self.__dict__.keys():
			return self.__dict__.get(key)
		return self.form.getvalue(key, '')
